@@ -1,6 +1,6 @@
 package WWW::Vimeo::Simple::User;
 {
-  $WWW::Vimeo::Simple::User::VERSION = '0.09';
+  $WWW::Vimeo::Simple::User::VERSION = '0.10';
 }
 
 use JSON;
@@ -22,7 +22,7 @@ WWW::Vimeo::Simple::User - User requests for the Vimeo Simple API
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -562,4 +562,8 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
+no Any::Moose;
+
+__PACKAGE__ -> meta -> make_immutable;
+
 1; # End of WWW::Vimeo::Simple::User
