@@ -1,6 +1,6 @@
 package WWW::Vimeo::Simple::User::Activity;
 {
-  $WWW::Vimeo::Simple::User::Activity::VERSION = '0.09';
+  $WWW::Vimeo::Simple::User::Activity::VERSION = '0.10';
 }
 
 use JSON;
@@ -18,7 +18,7 @@ WWW::Vimeo::Simple::User::Activity - Activity object
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 METHODS
 
@@ -335,4 +335,8 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
+no Any::Moose;
+
+__PACKAGE__ -> meta -> make_immutable;
+
 1; # End of WWW::Vimeo::Simple::User::Activity
